==> ups-3.32.tar.gz: ups-3.32/ups/menus/varmen.c <==
#include <stdio.h>
#include <local/menu3.h>

static MENU MM1 = {
	0x40,
	281,
	"&",
	100,
	-1,
	-1,
	35,
	27,
	26473,
	28270,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM2 = {
	0x40,
	25977,
	"*",
	117,
	35,
	-1,
	72,
	27,
	28769,
	26469,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM3 = {
	0x8,
	35,
	NULL,
	100,
	-1,
	-1,
	72,
	27,
	-30584,
	8738,
	0,
	0,
	0,
	NULL,
	&MM1,
	&MM2,
	NULL,
	NULL,
};
static MENU MM4 = {
	0x60,
	306,
	"Expand",
	69,
	72,
	-1,
	172,
	27,
	28252,
	2592,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM5 = {
	0x40,
	0,
	"First level",
	99,
	248,
	14,
	386,
	42,
	0,
	25888,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM6 = {
	0x40,
	26729,
	"Completely",
	67,
	248,
	42,
	386,
	71,
	28001,
	26988,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM7 = {
	0x404,
	42,
	NULL,
	2313,
	248,
	14,
	386,
	71,
	-17,
	-13,
	0,
	0,
	0,
	NULL,
	&MM5,
	&MM6,
	NULL,
	NULL,
};
static MENU MM8 = {
	0x2260,
	5272,
	"Collapse",
	63,
	172,
	-1,
	265,
	27,
	17251,
	11892,
	0,
	0,
	0,
	NULL,
	&MM7,
	NULL,
	NULL,
	NULL,
};
static MENU MM9 = {
	0x8,
	172,
	NULL,
	69,
	72,
	-1,
	265,
	27,
	25977,
	15955,
	0,
	0,
	0,
	NULL,
	&MM4,
	&MM8,
	NULL,
	NULL,
};
static MENU MM10 = {
	0x8,
	72,
	NULL,
	100,
	-1,
	-1,
	265,
	27,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM3,
	&MM9,
	NULL,
	NULL,
};
static MENU MM11 = {
	0x40,
	27765,
	"Dup",
	68,
	265,
	-1,
	341,
	27,
	21615,
	11842,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM12 = {
	0x40,
	25465,
	"Del",
	107,
	341,
	-1,
	417,
	27,
	29295,
	27756,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM13 = {
	0x8,
	341,
	NULL,
	68,
	265,
	-1,
	417,
	27,
	30568,
	26996,
	0,
	0,
	0,
	NULL,
	&MM11,
	&MM12,
	NULL,
	NULL,
};
static MENU MM14 = {
	0x40,
	8224,
	"Decimal",
	84,
	323,
	63,
	416,
	88,
	25701,
	27749,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM15 = {
	0x40,
	25925,
	"Octal",
	79,
	323,
	88,
	416,
	114,
	24864,
	15435,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM16 = {
	0x4,
	88,
	NULL,
	84,
	323,
	63,
	416,
	114,
	23662,
	23562,
	0,
	0,
	0,
	NULL,
	&MM14,
	&MM15,
	NULL,
	NULL,
};
static MENU MM17 = {
	0x40,
	25964,
	"Hex",
	72,
	323,
	114,
	416,
	139,
	28530,
	25640,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM18 = {
	0x40,
	17012,
	"Binary",
	66,
	323,
	139,
	416,
	165,
	26977,
	29541,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM19 = {
	0x4,
	139,
	NULL,
	72,
	323,
	114,
	416,
	165,
	27693,
	29807,
	0,
	0,
	0,
	NULL,
	&MM17,
	&MM18,
	NULL,
	NULL,
};
static MENU MM20 = {
	0x404,
	114,
	NULL,
	29793,
	323,
	63,
	416,
	165,
	31038,
	16698,
	0,
	0,
	0,
	NULL,
	&MM16,
	&MM19,
	NULL,
	NULL,
};
static MENU MM21 = {
	0x260,
	25964,
	"Unsigned",
	63,
	325,
	31,
	415,
	59,
	26721,
	29281,
	0,
	0,
	0,
	NULL,
	&MM20,
	NULL,
	NULL,
	NULL,
};
static MENU MM22 = {
	0x40,
	28261,
	"Decimal",
	116,
	413,
	64,
	506,
	89,
	8269,
	25972,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM23 = {
	0x40,
	10528,
	"Octal",
	111,
	413,
	89,
	506,
	114,
	31038,
	21306,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM24 = {
	0x40,
	11628,
	"Hex",
	104,
	413,
	114,
	506,
	139,
	25966,
	25645,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM25 = {
	0x4,
	114,
	NULL,
	111,
	413,
	89,
	506,
	139,
	25460,
	25970,
	0,
	0,
	0,
	NULL,
	&MM23,
	&MM24,
	NULL,
	NULL,
};
static MENU MM26 = {
	0x404,
	89,
	NULL,
	2592,
	413,
	64,
	506,
	139,
	2372,
	28484,
	0,
	0,
	0,
	NULL,
	&MM22,
	&MM25,
	NULL,
	NULL,
};
static MENU MM27 = {
	0x260,
	29485,
	"Signed",
	63,
	415,
	31,
	506,
	59,
	23562,
	8224,
	0,
	0,
	0,
	NULL,
	&MM26,
	NULL,
	NULL,
	NULL,
};
static MENU MM28 = {
	0x40,
	27680,
	"Default",
	110,
	506,
	62,
	617,
	88,
	28769,
	26469,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM29 = {
	0x40,
	29793,
	"Ascii",
	97,
	506,
	88,
	617,
	114,
	29800,
	26990,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM30 = {
	0x4,
	88,
	NULL,
	110,
	506,
	62,
	617,
	114,
	17268,
	29292,
	0,
	0,
	0,
	NULL,
	&MM28,
	&MM29,
	NULL,
	NULL,
};
static MENU MM31 = {
	0x40,
	28265,
	"String",
	115,
	506,
	114,
	617,
	140,
	28252,
	2592,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM32 = {
	0x40,
	2419,
	"RWCstring",
	98,
	506,
	140,
	617,
	167,
	11637,
	28712,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM33 = {
	0x4,
	140,
	NULL,
	115,
	506,
	114,
	617,
	167,
	28261,
	11628,
	0,
	0,
	0,
	NULL,
	&MM31,
	&MM32,
	NULL,
	NULL,
};
static MENU MM34 = {
	0x404,
	114,
	NULL,
	28260,
	506,
	62,
	617,
	167,
	25977,
	15954,
	0,
	0,
	0,
	NULL,
	&MM30,
	&MM33,
	NULL,
	NULL,
};
static MENU MM35 = {
	0x260,
	8284,
	"Other",
	98,
	506,
	31,
	597,
	59,
	15960,
	14857,
	0,
	0,
	0,
	NULL,
	&MM34,
	NULL,
	NULL,
	NULL,
};
static MENU MM36 = {
	0x8,
	506,
	NULL,
	63,
	415,
	31,
	597,
	59,
	25888,
	23662,
	0,
	0,
	0,
	NULL,
	&MM27,
	&MM35,
	NULL,
	NULL,
};
static MENU MM37 = {
	0x408,
	415,
	NULL,
	25955,
	325,
	31,
	597,
	59,
	28526,
	29498,
	0,
	0,
	0,
	NULL,
	&MM21,
	&MM36,
	NULL,
	NULL,
};
static MENU MM38 = {
	0x260,
	29285,
	"Format",
	63,
	417,
	-1,
	511,
	27,
	29797,
	11878,
	0,
	0,
	0,
	NULL,
	&MM37,
	NULL,
	NULL,
	NULL,
};
static MENU MM39 = {
	0x40,
	2372,
	"Use typedefs",
	85,
	584,
	24,
	726,
	49,
	28252,
	2592,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM40 = {
	0x40,
	23662,
	"Ignore typedefs",
	73,
	584,
	49,
	726,
	75,
	27194,
	2313,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM41 = {
	0x404,
	49,
	NULL,
	28535,
	584,
	24,
	726,
	75,
	-16,
	-3,
	0,
	0,
	0,
	NULL,
	&MM39,
	&MM40,
	NULL,
	NULL,
};
static MENU MM42 = {
	0x3260,
	25645,
	"Decl",
	113,
	511,
	-1,
	600,
	27,
	8224,
	20079,
	0,
	0,
	0,
	NULL,
	&MM41,
	NULL,
	NULL,
	NULL,
};
static MENU MM43 = {
	0x8,
	511,
	NULL,
	63,
	417,
	-1,
	600,
	27,
	30061,
	25146,
	0,
	0,
	0,
	NULL,
	&MM38,
	&MM42,
	NULL,
	NULL,
};
static MENU MM44 = {
	0x8,
	417,
	NULL,
	68,
	265,
	-1,
	600,
	27,
	24946,
	10822,
	0,
	0,
	0,
	NULL,
	&MM13,
	&MM43,
	NULL,
	NULL,
};
MENU var_men = {
	0x408,
	265,
	NULL,
	30062,
	-1,
	-1,
	600,
	27,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM10,
	&MM44,
	NULL,
	NULL,
};

==> ups-3.33.tar.gz: ups-3.33/ups/menus/varmen.c <==
#include <stdio.h>
#include <local/menu3.h>

static MENU MM1 = {
	0x40,
	0,
	"&",
	100,
	-1,
	-1,
	35,
	26,
	-13216,
	24940,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM2 = {
	0x40,
	0,
	"*",
	117,
	35,
	-1,
	72,
	26,
	-13216,
	28192,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM3 = {
	0x8,
	35,
	NULL,
	100,
	-1,
	-1,
	72,
	26,
	-13216,
	2643,
	0,
	0,
	0,
	NULL,
	&MM1,
	&MM2,
	NULL,
	NULL,
};
static MENU MM4 = {
	0x40,
	0,
	"::",
	121,
	72,
	-1,
	109,
	26,
	-13216,
	26656,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM5 = {
	0x40,
	0,
	"Struct/Union",
	69,
	180,
	15,
	325,
	45,
	-13216,
	25455,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM6 = {
	0x40,
	0,
	"Class Hierarchy",
	121,
	180,
	45,
	325,
	75,
	-13216,
	28261,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM7 = {
	0x40,
	0,
	"Static Members",
	83,
	180,
	75,
	325,
	106,
	-13216,
	28192,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM8 = {
	0x4,
	75,
	NULL,
	121,
	180,
	45,
	325,
	106,
	-13216,
	29305,
	0,
	0,
	0,
	NULL,
	&MM6,
	&MM7,
	NULL,
	NULL,
};
static MENU MM9 = {
	0x404,
	45,
	NULL,
	0,
	180,
	15,
	325,
	106,
	-23,
	-11,
	0,
	0,
	0,
	NULL,
	&MM5,
	&MM8,
	NULL,
	NULL,
};
static MENU MM10 = {
	0x2260,
	0,
	"Expand",
	69,
	109,
	-1,
	203,
	26,
	-13216,
	30066,
	0,
	0,
	0,
	NULL,
	&MM9,
	NULL,
	NULL,
	NULL,
};
static MENU MM11 = {
	0x8,
	109,
	NULL,
	121,
	72,
	-1,
	203,
	26,
	-13216,
	26982,
	0,
	0,
	0,
	NULL,
	&MM4,
	&MM10,
	NULL,
	NULL,
};
static MENU MM12 = {
	0x8,
	72,
	NULL,
	100,
	-1,
	-1,
	203,
	26,
	-13216,
	0,
	0,
	0,
	0,
	NULL,
	&MM3,
	&MM11,
	NULL,
	NULL,
};
static MENU MM13 = {
	0x40,
	0,
	"First level",
	99,
	279,
	14,
	417,
	42,
	-13216,
	29285,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM14 = {
	0x40,
	0,
	"Completely",
	67,
	279,
	42,
	417,
	71,
	-13216,
	24931,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM15 = {
	0x404,
	42,
	NULL,
	0,
	279,
	14,
	417,
	71,
	-35,
	-12,
	0,
	0,
	0,
	NULL,
	&MM13,
	&MM14,
	NULL,
	NULL,
};
static MENU MM16 = {
	0x2260,
	0,
	"Collapse",
	63,
	203,
	-1,
	314,
	26,
	-13216,
	8276,
	0,
	0,
	0,
	NULL,
	&MM15,
	NULL,
	NULL,
	NULL,
};
static MENU MM17 = {
	0x40,
	0,
	"Dup",
	68,
	314,
	-1,
	371,
	26,
	-13216,
	25957,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM18 = {
	0x8,
	314,
	NULL,
	63,
	203,
	-1,
	371,
	26,
	-13216,
	28276,
	0,
	0,
	0,
	NULL,
	&MM16,
	&MM17,
	NULL,
	NULL,
};
static MENU MM19 = {
	0x40,
	0,
	"Del",
	107,
	371,
	-1,
	436,
	26,
	-13216,
	28259,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM20 = {
	0x40,
	0,
	"Decimal",
	84,
	342,
	63,
	435,
	88,
	0,
	25955,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM21 = {
	0x40,
	0,
	"Octal",
	79,
	342,
	88,
	435,
	114,
	0,
	28483,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM22 = {
	0x4,
	88,
	NULL,
	84,
	342,
	63,
	435,
	114,
	0,
	29485,
	0,
	0,
	0,
	NULL,
	&MM20,
	&MM21,
	NULL,
	NULL,
};
static MENU MM23 = {
	0x40,
	0,
	"Hex",
	72,
	342,
	114,
	435,
	139,
	0,
	2592,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM24 = {
	0x40,
	0,
	"Binary",
	66,
	342,
	139,
	435,
	165,
	0,
	8284,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM25 = {
	0x4,
	139,
	NULL,
	72,
	342,
	114,
	435,
	165,
	0,
	25977,
	0,
	0,
	0,
	NULL,
	&MM23,
	&MM24,
	NULL,
	NULL,
};
static MENU MM26 = {
	0x404,
	114,
	NULL,
	0,
	342,
	63,
	435,
	165,
	-13216,
	12868,
	0,
	0,
	0,
	NULL,
	&MM22,
	&MM25,
	NULL,
	NULL,
};
static MENU MM27 = {
	0x260,
	0,
	"Unsigned",
	63,
	344,
	31,
	434,
	59,
	-13216,
	25185,
	0,
	0,
	0,
	NULL,
	&MM26,
	NULL,
	NULL,
	NULL,
};
static MENU MM28 = {
	0x40,
	0,
	"Decimal",
	116,
	432,
	64,
	525,
	89,
	0,
	23662,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM29 = {
	0x40,
	0,
	"Octal",
	111,
	432,
	89,
	525,
	114,
	0,
	25955,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM30 = {
	0x40,
	0,
	"Hex",
	104,
	432,
	114,
	525,
	139,
	0,
	28734,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM31 = {
	0x4,
	114,
	NULL,
	111,
	432,
	89,
	525,
	139,
	0,
	25189,
	0,
	0,
	0,
	NULL,
	&MM29,
	&MM30,
	NULL,
	NULL,
};
static MENU MM32 = {
	0x404,
	89,
	NULL,
	26482,
	432,
	64,
	525,
	139,
	0,
	25956,
	0,
	0,
	0,
	NULL,
	&MM28,
	&MM31,
	NULL,
	NULL,
};
static MENU MM33 = {
	0x260,
	0,
	"Signed",
	63,
	434,
	31,
	525,
	59,
	0,
	25956,
	0,
	0,
	0,
	NULL,
	&MM32,
	NULL,
	NULL,
	NULL,
};
static MENU MM34 = {
	0x40,
	0,
	"Default",
	110,
	525,
	62,
	636,
	88,
	0,
	30309,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM35 = {
	0x40,
	0,
	"Ascii",
	97,
	525,
	88,
	636,
	114,
	0,
	8224,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM36 = {
	0x4,
	88,
	NULL,
	110,
	525,
	62,
	636,
	114,
	0,
	8284,
	0,
	0,
	0,
	NULL,
	&MM34,
	&MM35,
	NULL,
	NULL,
};
static MENU MM37 = {
	0x40,
	0,
	"String",
	115,
	525,
	114,
	636,
	140,
	0,
	25972,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM38 = {
	0x40,
	0,
	"RWCstring",
	98,
	525,
	140,
	636,
	167,
	0,
	11619,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM39 = {
	0x4,
	140,
	NULL,
	115,
	525,
	114,
	636,
	167,
	0,
	25977,
	0,
	0,
	0,
	NULL,
	&MM37,
	&MM38,
	NULL,
	NULL,
};
static MENU MM40 = {
	0x404,
	114,
	NULL,
	10868,
	525,
	62,
	636,
	167,
	0,
	8224,
	0,
	0,
	0,
	NULL,
	&MM36,
	&MM39,
	NULL,
	NULL,
};
static MENU MM41 = {
	0x260,
	0,
	"Other",
	98,
	525,
	31,
	616,
	59,
	0,
	18533,
	0,
	0,
	0,
	NULL,
	&MM40,
	NULL,
	NULL,
	NULL,
};
static MENU MM42 = {
	0x8,
	525,
	NULL,
	63,
	434,
	31,
	616,
	59,
	0,
	25460,
	0,
	0,
	0,
	NULL,
	&MM33,
	&MM41,
	NULL,
	NULL,
};
static MENU MM43 = {
	0x408,
	434,
	NULL,
	22377,
	344,
	31,
	616,
	59,
	-13216,
	24942,
	0,
	0,
	0,
	NULL,
	&MM27,
	&MM42,
	NULL,
	NULL,
};
static MENU MM44 = {
	0x260,
	0,
	"Format",
	63,
	436,
	-1,
	527,
	26,
	-13216,
	24931,
	0,
	0,
	0,
	NULL,
	&MM43,
	NULL,
	NULL,
	NULL,
};
static MENU MM45 = {
	0x40,
	0,
	"Use typedefs",
	85,
	600,
	24,
	742,
	49,
	0,
	28252,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM46 = {
	0x40,
	0,
	"Ignore typedefs",
	73,
	600,
	49,
	742,
	75,
	0,
	20079,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM47 = {
	0x404,
	49,
	NULL,
	28533,
	600,
	24,
	742,
	75,
	0,
	-2,
	0,
	0,
	0,
	NULL,
	&MM45,
	&MM46,
	NULL,
	NULL,
};
static MENU MM48 = {
	0x3260,
	0,
	"Decl",
	113,
	527,
	-1,
	600,
	26,
	0,
	21306,
	0,
	0,
	0,
	NULL,
	&MM47,
	NULL,
	NULL,
	NULL,
};
static MENU MM49 = {
	0x8,
	527,
	NULL,
	63,
	436,
	-1,
	600,
	26,
	-13216,
	28526,
	0,
	0,
	0,
	NULL,
	&MM44,
	&MM48,
	NULL,
	NULL,
};
static MENU MM50 = {
	0x8,
	436,
	NULL,
	107,
	371,
	-1,
	600,
	26,
	-13216,
	12320,
	0,
	0,
	0,
	NULL,
	&MM19,
	&MM49,
	NULL,
	NULL,
};
static MENU MM51 = {
	0x8,
	371,
	NULL,
	63,
	203,
	-1,
	600,
	26,
	-13216,
	30062,
	0,
	0,
	0,
	NULL,
	&MM18,
	&MM50,
	NULL,
	NULL,
};
MENU var_men = {
	0x408,
	203,
	NULL,
	2313,
	-1,
	-1,
	600,
	26,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM12,
	&MM51,
	NULL,
	NULL,
};
